// TicTacToeController.java
import java.util.Scanner;

public class TicTacToeController {

    private TicTacToeModel model;
    private TicTacToeView view;
    private Scanner scanner;

    /**
     * Constructs the controller with the given model and view.
     *
     * @param m The game model.
     * @param v The game view.
     */
    public TicTacToeController(TicTacToeModel m, TicTacToeView v) {
        model = m;
        view = v;
        scanner = new Scanner(System.in);
    }

    /**
     * Starts the game loop.
     */
    public void startGame() {
        boolean gameEnded = false;
        while (!gameEnded) {
            view.displayBoard();
            //todo: finish the implementation
        }
        view.displayMessage("Game over.");
    }

    /**
     * Prompts the current player for their move.
     *
     * @param currentPlayer The current player.
     * @return An array containing the row and column.
     */
    private int[] getMove(int currentPlayer) {
        while (true) {
            try {
                view.displayMessage("Player " + (currentPlayer == TicTacToeModel.PLAYER_X ? "X" : "O") + ", enter your move (row and column): ");
                String input = scanner.nextLine();
                String[] tokens = input.trim().split("\\s+");
                if (tokens.length != 2) {
                    view.displayMessage("Invalid input. Please enter two numbers separated by space.");
                    continue;
                }
                int row = Integer.parseInt(tokens[0]);
                int col = Integer.parseInt(tokens[1]);
                if (row < 0 || row > 2 || col < 0 || col > 2) {
                    view.displayMessage("Invalid move. Row and column must be between 0 and 2.");
                    continue;
                }
                return new int[]{row, col};
            } catch (NumberFormatException e) {
                view.displayMessage("Invalid input. Please enter numbers.");
            }
        }
    }
}
