// TicTacToeModel.java
public class TicTacToeModel {

    public static final int EMPTY = 0;
    public static final int PLAYER_X = 1;
    public static final int PLAYER_O = 2;

    private int[][] board;
    private int currentPlayer;

    public TicTacToeModel() {
        board = new int[3][3];
        currentPlayer = PLAYER_X;
    }

    public int[][] getBoard() {
        return board;
    }

    public int getCurrentPlayer() {
        return currentPlayer;
    }

    public void resetGame() {
        board = new int[3][3];
        currentPlayer = PLAYER_X;
    }

    public boolean makeMove(int row, int col) {
        if (board[row][col] == EMPTY) {
            board[row][col] = currentPlayer;
            // Switch player
            currentPlayer = (currentPlayer == PLAYER_X) ? PLAYER_O : PLAYER_X;
            return true;
        } else {
            return false;
        }
    }

    public int getCell(int row, int col) {
        return board[row][col];
    }

    public int checkWin() {
        // Check rows
        for (int i = 0; i < 3; i++) {
            if (board[i][0] != EMPTY &&
                    board[i][0] == board[i][1] &&
                    board[i][1] == board[i][2]) {
                return board[i][0];
            }
        }

        // Check columns
        for (int j = 0; j < 3; j++) {
            if (board[0][j] != EMPTY &&
                    board[0][j] == board[1][j] &&
                    board[1][j] == board[2][j]) {
                return board[0][j];
            }
        }

        // Check diagonals
        if (board[0][0] != EMPTY &&
                board[0][0] == board[1][1] &&
                board[1][1] == board[2][2]) {
            return board[0][0];
        }

        if (board[0][2] != EMPTY &&
                board[0][2] == board[1][1] &&
                board[1][1] == board[2][0]) {
            return board[0][2];
        }

        // Check for draw
        boolean full = true;
        for (int i = 0; i < 3; i++) {
            for (int j = 0; j < 3; j++) {
                if (board[i][j] == EMPTY) {
                    full = false;
                    break;
                }
            }
        }

        if (full) {
            return -1; // Draw
        }

        return EMPTY; // No winner yet
    }
}
